.. _evaluation:

Synthetic Data Evaluation
=========================

After creating synthetic data, you may be wondering how you can evaluate
it against the original data. You can use the `SDMetrics library 
<https://github.com/sdv-dev/SDMetrics>`__ to get more insights, generate
reports and visualize the data. This library is automatically installed with SDV.

To get started, visit: https://docs.sdv.dev/sdmetrics/

.. toctree::
    :titlesonly:

    evaluation_framework
    synthetic_data_metrics
